BankCategory class

Constructors

BankCategory({String? paymentTypeId, String? methodName, String? methodId, String? idCategory, String? code, String? name, String? description, String? paymentTypeName})
BankCategory.fromJson(Map<String, dynamic> json)

Properties

code String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idCategory String?
getter/setter pair
methodId String?
getter/setter pair
methodName String?
getter/setter pair
name String?
getter/setter pair
paymentTypeId String?
getter/setter pair
paymentTypeName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited