PaymentTypeGroup class

Constructors

PaymentTypeGroup({String? name, String? description, String? code, String? label, String? isManualInput, int? paymentSpecId, List<BankCategory>? bankCategory})
PaymentTypeGroup.fromJson(Map<String, dynamic> json)

Properties

bankCategory List<BankCategory>?
getter/setter pair
code String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isManualInput String?
getter/setter pair
label String?
getter/setter pair
name String?
getter/setter pair
paymentSpecId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited